@@ -648,7 +648,7 @@ class EmergePackage(Mapping):
     pv = r"(?:-(\d[^-]*?))?"
     pr = r"(?:-(r\d+))?"
     tbz = r"(?:.(tbz2))?"
-    slot = r'(?::(\w+(?:\.\w+)*(?:/\w+(?:\.\w+)*)?))?'
+    slot = r'(?::(\w+(?:\.\w+)*(?:/\w+(?:\.\w+)*(?:-\w+(?:\.\w+)*)?)?))?'
     repo = r'(?:::(\w+))?'
 
     reParse = re.compile(
